==> zio-aws-codedeploy_3-5.17.154.1-sources.jar: zio/aws/codedeploy/model/LambdaTarget.scala <==
package zio.aws.codedeploy.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codedeploy.model.primitives.{
  Time,
  TargetArn,
  TargetId,
  DeploymentId
}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class LambdaTarget(
    deploymentId: Option[DeploymentId] = None,
    targetId: Option[TargetId] = None,
    targetArn: Option[TargetArn] = None,
    status: Option[zio.aws.codedeploy.model.TargetStatus] = None,
    lastUpdatedAt: Option[Time] = None,
    lifecycleEvents: Option[Iterable[zio.aws.codedeploy.model.LifecycleEvent]] =
      None,
    lambdaFunctionInfo: Option[zio.aws.codedeploy.model.LambdaFunctionInfo] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codedeploy.model.LambdaTarget = {
    import LambdaTarget.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codedeploy.model.LambdaTarget
      .builder()
      .optionallyWith(
        deploymentId.map(value => DeploymentId.unwrap(value): java.lang.String)
      )(_.deploymentId)
      .optionallyWith(
        targetId.map(value => TargetId.unwrap(value): java.lang.String)
      )(_.targetId)
      .optionallyWith(
        targetArn.map(value => TargetArn.unwrap(value): java.lang.String)
      )(_.targetArn)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(lastUpdatedAt.map(value => Time.unwrap(value): Instant))(
        _.lastUpdatedAt
      )
      .optionallyWith(
        lifecycleEvents.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.lifecycleEvents)
      .optionallyWith(lambdaFunctionInfo.map(value => value.buildAwsValue()))(
        _.lambdaFunctionInfo
      )
      .build()
  }
  def asReadOnly: zio.aws.codedeploy.model.LambdaTarget.ReadOnly =
    zio.aws.codedeploy.model.LambdaTarget.wrap(buildAwsValue())
}
object LambdaTarget {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codedeploy.model.LambdaTarget
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codedeploy.model.LambdaTarget =
      zio.aws.codedeploy.model.LambdaTarget(
        deploymentId.map(value => value),
        targetId.map(value => value),
        targetArn.map(value => value),
        status.map(value => value),
        lastUpdatedAt.map(value => value),
        lifecycleEvents.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        lambdaFunctionInfo.map(value => value.asEditable)
      )
    def deploymentId: Option[DeploymentId]
    def targetId: Option[TargetId]
    def targetArn: Option[TargetArn]
    def status: Option[zio.aws.codedeploy.model.TargetStatus]
    def lastUpdatedAt: Option[Time]
    def lifecycleEvents
        : Option[List[zio.aws.codedeploy.model.LifecycleEvent.ReadOnly]]
    def lambdaFunctionInfo
        : Option[zio.aws.codedeploy.model.LambdaFunctionInfo.ReadOnly]
    def getDeploymentId: ZIO[Any, AwsError, DeploymentId] =
      AwsError.unwrapOptionField("deploymentId", deploymentId)
    def getTargetId: ZIO[Any, AwsError, TargetId] =
      AwsError.unwrapOptionField("targetId", targetId)
    def getTargetArn: ZIO[Any, AwsError, TargetArn] =
      AwsError.unwrapOptionField("targetArn", targetArn)
    def getStatus: ZIO[Any, AwsError, zio.aws.codedeploy.model.TargetStatus] =
      AwsError.unwrapOptionField("status", status)
    def getLastUpdatedAt: ZIO[Any, AwsError, Time] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getLifecycleEvents: ZIO[Any, AwsError, List[
      zio.aws.codedeploy.model.LifecycleEvent.ReadOnly
    ]] = AwsError.unwrapOptionField("lifecycleEvents", lifecycleEvents)
    def getLambdaFunctionInfo: ZIO[
      Any,
      AwsError,
      zio.aws.codedeploy.model.LambdaFunctionInfo.ReadOnly
    ] = AwsError.unwrapOptionField("lambdaFunctionInfo", lambdaFunctionInfo)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codedeploy.model.LambdaTarget
  ) extends zio.aws.codedeploy.model.LambdaTarget.ReadOnly {
    override val deploymentId: Option[DeploymentId] = scala
      .Option(impl.deploymentId())
      .map(value => zio.aws.codedeploy.model.primitives.DeploymentId(value))
    override val targetId: Option[TargetId] = scala
      .Option(impl.targetId())
      .map(value => zio.aws.codedeploy.model.primitives.TargetId(value))
    override val targetArn: Option[TargetArn] = scala
      .Option(impl.targetArn())
      .map(value => zio.aws.codedeploy.model.primitives.TargetArn(value))
    override val status: Option[zio.aws.codedeploy.model.TargetStatus] = scala
      .Option(impl.status())
      .map(value => zio.aws.codedeploy.model.TargetStatus.wrap(value))
    override val lastUpdatedAt: Option[Time] = scala
      .Option(impl.lastUpdatedAt())
      .map(value => zio.aws.codedeploy.model.primitives.Time(value))
    override val lifecycleEvents
        : Option[List[zio.aws.codedeploy.model.LifecycleEvent.ReadOnly]] = scala
      .Option(impl.lifecycleEvents())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codedeploy.model.LifecycleEvent.wrap(item)
        }.toList
      )
    override val lambdaFunctionInfo
        : Option[zio.aws.codedeploy.model.LambdaFunctionInfo.ReadOnly] = scala
      .Option(impl.lambdaFunctionInfo())
      .map(value => zio.aws.codedeploy.model.LambdaFunctionInfo.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codedeploy.model.LambdaTarget
  ): zio.aws.codedeploy.model.LambdaTarget.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codedeploy_3-6.20.69.1-sources.jar: zio/aws/codedeploy/model/LambdaTarget.scala <==
package zio.aws.codedeploy.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.codedeploy.model.primitives.{
  Time,
  TargetArn,
  TargetId,
  DeploymentId
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class LambdaTarget(
    deploymentId: Optional[DeploymentId] = Optional.Absent,
    targetId: Optional[TargetId] = Optional.Absent,
    targetArn: Optional[TargetArn] = Optional.Absent,
    status: Optional[zio.aws.codedeploy.model.TargetStatus] = Optional.Absent,
    lastUpdatedAt: Optional[Time] = Optional.Absent,
    lifecycleEvents: Optional[
      Iterable[zio.aws.codedeploy.model.LifecycleEvent]
    ] = Optional.Absent,
    lambdaFunctionInfo: Optional[zio.aws.codedeploy.model.LambdaFunctionInfo] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codedeploy.model.LambdaTarget = {
    import LambdaTarget.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codedeploy.model.LambdaTarget
      .builder()
      .optionallyWith(
        deploymentId.map(value => DeploymentId.unwrap(value): java.lang.String)
      )(_.deploymentId)
      .optionallyWith(
        targetId.map(value => TargetId.unwrap(value): java.lang.String)
      )(_.targetId)
      .optionallyWith(
        targetArn.map(value => TargetArn.unwrap(value): java.lang.String)
      )(_.targetArn)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(lastUpdatedAt.map(value => Time.unwrap(value): Instant))(
        _.lastUpdatedAt
      )
      .optionallyWith(
        lifecycleEvents.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.lifecycleEvents)
      .optionallyWith(lambdaFunctionInfo.map(value => value.buildAwsValue()))(
        _.lambdaFunctionInfo
      )
      .build()
  }
  def asReadOnly: zio.aws.codedeploy.model.LambdaTarget.ReadOnly =
    zio.aws.codedeploy.model.LambdaTarget.wrap(buildAwsValue())
}
object LambdaTarget {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codedeploy.model.LambdaTarget
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codedeploy.model.LambdaTarget =
      zio.aws.codedeploy.model.LambdaTarget(
        deploymentId.map(value => value),
        targetId.map(value => value),
        targetArn.map(value => value),
        status.map(value => value),
        lastUpdatedAt.map(value => value),
        lifecycleEvents.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        lambdaFunctionInfo.map(value => value.asEditable)
      )
    def deploymentId: Optional[DeploymentId]
    def targetId: Optional[TargetId]
    def targetArn: Optional[TargetArn]
    def status: Optional[zio.aws.codedeploy.model.TargetStatus]
    def lastUpdatedAt: Optional[Time]
    def lifecycleEvents
        : Optional[List[zio.aws.codedeploy.model.LifecycleEvent.ReadOnly]]
    def lambdaFunctionInfo
        : Optional[zio.aws.codedeploy.model.LambdaFunctionInfo.ReadOnly]
    def getDeploymentId: ZIO[Any, AwsError, DeploymentId] =
      AwsError.unwrapOptionField("deploymentId", deploymentId)
    def getTargetId: ZIO[Any, AwsError, TargetId] =
      AwsError.unwrapOptionField("targetId", targetId)
    def getTargetArn: ZIO[Any, AwsError, TargetArn] =
      AwsError.unwrapOptionField("targetArn", targetArn)
    def getStatus: ZIO[Any, AwsError, zio.aws.codedeploy.model.TargetStatus] =
      AwsError.unwrapOptionField("status", status)
    def getLastUpdatedAt: ZIO[Any, AwsError, Time] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getLifecycleEvents: ZIO[Any, AwsError, List[
      zio.aws.codedeploy.model.LifecycleEvent.ReadOnly
    ]] = AwsError.unwrapOptionField("lifecycleEvents", lifecycleEvents)
    def getLambdaFunctionInfo: ZIO[
      Any,
      AwsError,
      zio.aws.codedeploy.model.LambdaFunctionInfo.ReadOnly
    ] = AwsError.unwrapOptionField("lambdaFunctionInfo", lambdaFunctionInfo)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codedeploy.model.LambdaTarget
  ) extends zio.aws.codedeploy.model.LambdaTarget.ReadOnly {
    override val deploymentId: Optional[DeploymentId] = zio.aws.core.internal
      .optionalFromNullable(impl.deploymentId())
      .map(value => zio.aws.codedeploy.model.primitives.DeploymentId(value))
    override val targetId: Optional[TargetId] = zio.aws.core.internal
      .optionalFromNullable(impl.targetId())
      .map(value => zio.aws.codedeploy.model.primitives.TargetId(value))
    override val targetArn: Optional[TargetArn] = zio.aws.core.internal
      .optionalFromNullable(impl.targetArn())
      .map(value => zio.aws.codedeploy.model.primitives.TargetArn(value))
    override val status: Optional[zio.aws.codedeploy.model.TargetStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.codedeploy.model.TargetStatus.wrap(value))
    override val lastUpdatedAt: Optional[Time] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdatedAt())
      .map(value => zio.aws.codedeploy.model.primitives.Time(value))
    override val lifecycleEvents
        : Optional[List[zio.aws.codedeploy.model.LifecycleEvent.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lifecycleEvents())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.codedeploy.model.LifecycleEvent.wrap(item)
          }.toList
        )
    override val lambdaFunctionInfo
        : Optional[zio.aws.codedeploy.model.LambdaFunctionInfo.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lambdaFunctionInfo())
        .map(value => zio.aws.codedeploy.model.LambdaFunctionInfo.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codedeploy.model.LambdaTarget
  ): zio.aws.codedeploy.model.LambdaTarget.ReadOnly = new Wrapper(impl)
}
